##  The entry-level approach
Especially in the first few weeks, we recommend beginning with the following approach:
  * Use tag groups to model IT components, e.g. create a tag group “Application Hosting” and assign values such as “On-Prem” / “SaaS” / “PaaS” / “IaaS”.
  * Assign colors in relation to your IT strategy, e.g. if you have the paradigm to go "cloud-first", color “On-Prem” red
  * The "Application Hosting" view of the Application Landscape and the Application Matrix reports will provide you with an immediate overview.
  * Filter the Application Roadmap report by tag group, e.g. to show all lifecycles with “On-Prem” applications in case you want to decommission them.
  * Assign the tags to your Application Fact Sheets manually or via the .xls upload.


The following screenshot shows an example of using the entry-level approach:
![2018](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756979d7a44101490b38ed70d73d18a_LowRes.png)
